@@ -189,13 +189,15 @@ class _config(_base_config):
         The notification to display when the application is ready and
         fully loaded.""")
 
-    reuse_sessions = param.Boolean(default=False, doc="""
+    reuse_sessions = param.Selector(default=False, objects=[True, False, 'warm'], doc="""
         Whether to reuse a session for the initial request to speed up
         the initial page render. Note that if the initial page differs
         between sessions, e.g. because it uses query parameters to modify
         the rendered content, then this option will result in the wrong
         content being rendered. Define a session_key_func to ensure that
-        reused sessions are only reused when appropriate.""")
+        reused sessions are only reused when appropriate. If set to 'warm'
+        session reuse is enabled and the session is warmed up as soon as
+        the initial request arrives.""")
 
     session_key_func = param.Callable(default=None, doc="""
         Used in conjunction with the reuse_sessions option, the
@@ -878,7 +880,10 @@ class panel_extension(_pyviz_extension):
                 nb_loaded = True
             else:
                 with param.logging_level('ERROR'):
-                    hv.plotting.Renderer.load_nb(config.inline)
+                    hv.plotting.Renderer.load_nb(
+                        config.inline,
+                        enable_mathjax="mathjax" in panel_extension._loaded_extensions
+                    )
                     nb_loaded = True
 
         # Disable simple ids, old state and multiple tabs in notebooks can cause IDs to clash
