@@ -1039,6 +1039,9 @@ export class DataTabulatorView extends HTMLBoxView {
       if (tab_column.title == null) {
         tab_column.title = column.title
       }
+      if (tab_column.headerTooltip === undefined) {
+        tab_column.headerTooltip = true
+      }
       if (tab_column.width == null && column.width != null && column.width != 0) {
         tab_column.width = column.width
       }
