@@ -93,7 +93,7 @@ class Bokeh(Pane):
 
     def _param_change(self, *events: param.parameterized.Event) -> None:
         self._track_overrides(*(e for e in events if e.name in Layoutable.param))
-        super()._param_change(*(e for e in events if e.name in self._overrides+['css_classes']))
+        super()._param_change(*(e for e in events if e.name in self._overrides+['css_classes', 'visible']))
 
     @classmethod
     def applies(cls, obj: Any) -> float | bool | None:
