@@ -9,8 +9,9 @@ import sys
 import zipfile
 
 from abc import abstractmethod
+from collections.abc import Mapping
 from typing import (
-    IO, TYPE_CHECKING, Any, ClassVar, Mapping, Optional,
+    IO, TYPE_CHECKING, Any, ClassVar,
 )
 from urllib.request import urlopen
 
@@ -83,7 +84,7 @@ class AbstractVTK(Pane):
 
     def _update_model(
         self, events: dict[str, param.parameterized.Event], msg: dict[str, Any],
-        root: Model, model: Model, doc: Document, comm: Optional[Comm]
+        root: Model, model: Model, doc: Document, comm: Comm | None
     ) -> None:
         if 'axes' in msg and msg['axes'] is not None:
             VTKAxes = sys.modules['panel.models.vtk'].VTKAxes
@@ -376,14 +377,14 @@ class VTKRenderWindow(BaseVTKRenderWindow):
                 serialize_on_instantiation)
 
     def __init__(self, object=None, **params):
-        super(VTKRenderWindow, self).__init__(object, **params)
+        super().__init__(object, **params)
         if object is not None:
             self.color_mappers = self.get_color_mappers()
             self._update(None, None)
 
     def _get_model(
-        self, doc: Document, root: Optional[Model] = None,
-        parent: Optional[Model] = None, comm: Optional[Comm] = None
+        self, doc: Document, root: Model | None = None,
+        parent: Model | None = None, comm: Comm | None = None
     ) -> Model:
         VTKSynchronizedPlot = lazy_load(
             'panel.models.vtk', 'VTKSynchronizedPlot', isinstance(comm, JupyterComm), root
@@ -443,8 +444,8 @@ class VTKRenderWindowSynchronized(BaseVTKRenderWindow, SyncHelpers):
         self._contexts = {}
 
     def _get_model(
-        self, doc: Document, root: Optional[Model] = None,
-        parent: Optional[Model] = None, comm: Optional[Comm] = None
+        self, doc: Document, root: Model | None = None,
+        parent: Model | None = None, comm: Comm | None = None
     ) -> Model:
         VTKSynchronizedPlot = lazy_load(
             'panel.models.vtk', 'VTKSynchronizedPlot', isinstance(comm, JupyterComm), root
@@ -468,8 +469,9 @@ class VTKRenderWindowSynchronized(BaseVTKRenderWindow, SyncHelpers):
         return model
 
     def _cleanup(self, root: Model | None = None) -> None:
-        ref = root.ref['id']
-        self._contexts.pop(ref, None)
+        if root:
+            ref = root.ref['id']
+            self._contexts.pop(ref, None)
         super()._cleanup(root)
 
     def _update(self, ref: str, model: Model) -> None:
@@ -638,7 +640,7 @@ class VTKVolume(AbstractVTK):
         Integer parameter to control the position of the slice normal
         to the Z direction.""")
 
-    _serializers = {}
+    _serializers: dict[type, Any] = {}
 
     _rename: ClassVar[Mapping[str, str | None]] = {'max_data_size': None, 'spacing': None, 'origin': None}
 
@@ -661,8 +663,8 @@ class VTKVolume(AbstractVTK):
             return isinstance(obj, vtk.vtkImageData)
 
     def _get_model(
-        self, doc: Document, root: Optional[Model] = None,
-        parent: Optional[Model] = None, comm: Optional[Comm] = None
+        self, doc: Document, root: Model | None = None,
+        parent: Model | None = None, comm: Comm | None = None
     ) -> Model:
         VTKVolumePlot = lazy_load(
             'panel.models.vtk', 'VTKVolumePlot', isinstance(comm, JupyterComm), root
@@ -733,7 +735,7 @@ class VTKVolume(AbstractVTK):
         A serializer is a function which take an instance of `class_type`
         (like a vtk.vtkImageData) as input and return a numpy array of the data
         """
-        cls._serializers.update({class_type:serializer})
+        cls._serializers.update({class_type: serializer})
 
     def _volume_from_array(self, sub_array):
         return dict(
@@ -820,7 +822,7 @@ class VTKJS(AbstractVTK):
                  notebook context if they interact with already
                  bound keys.""")
 
-    _serializers = {}
+    _serializers: dict[type, Any] = {}
 
     _updates = True
 
@@ -832,10 +834,11 @@ class VTKJS(AbstractVTK):
     def applies(cls, obj: Any) -> float | bool | None:
         if isinstance(obj, str) and obj.endswith('.vtkjs'):
             return True
+        return None
 
     def _get_model(
-        self, doc: Document, root: Optional[Model] = None,
-        parent: Optional[Model] = None, comm: Optional[Comm] = None
+        self, doc: Document, root: Model | None = None,
+        parent: Model | None = None, comm: Comm | None = None
     ) -> Model:
         """
         Should return the bokeh model to be rendered.
