@@ -1,4 +1,4 @@
-from datetime import date, datetime
+from datetime import date, datetime, time as dt_time
 from pathlib import Path
 
 import numpy as np
@@ -10,7 +10,7 @@ from panel import config
 from panel.widgets import (
     ArrayInput, Checkbox, DatePicker, DateRangePicker, DatetimeInput,
     DatetimePicker, DatetimeRangeInput, DatetimeRangePicker, FileInput,
-    FloatInput, IntInput, LiteralInput, StaticText, TextInput,
+    FloatInput, IntInput, LiteralInput, StaticText, TextInput, TimePicker,
 )
 
 
@@ -185,6 +185,22 @@ def test_datetime_range_picker(document, comm):
         datetime_range_picker._process_events({'value': '2018-09-10 00:00:01'})
 
 
+def test_time_picker(document, comm):
+    time_picker = TimePicker(name='Time Picker', value=dt_time(hour=18), format='H:i K')
+    assert time_picker.value == dt_time(hour=18)
+    assert time_picker.format == 'H:i K'
+    assert time_picker.start is None
+    assert time_picker.end is None
+
+
+def test_time_picker_str(document, comm):
+    time_picker = TimePicker(name='Time Picker', value="08:28", start='00:00', end='12:00')
+    assert time_picker.value == "08:28"
+    assert time_picker.format == 'H:i'
+    assert time_picker.start == "00:00"
+    assert time_picker.end == "12:00"
+
+
 def test_file_input(document, comm):
     file_input = FileInput(accept='.txt')
 
@@ -228,7 +244,6 @@ def test_literal_input(document, comm):
     with pytest.raises(ValueError):
         literal.value = []
 
-
 def test_static_text(document, comm):
 
     text = StaticText(value='ABC', name='Text:')
@@ -244,6 +259,31 @@ def test_static_text(document, comm):
     text.value = '<b>Text:</b>: ABC'
     assert widget.text == '<b>Text:</b>: ABC'
 
+def test_static_text_no_sync(document, comm):
+    text = StaticText(value='ABC', name='Text:')
+
+    widget = text.get_root(document, comm=comm)
+
+    widget.text = 'CBA'
+    assert text.value == 'ABC'
+
+def test_static_text_empty(document, comm):
+
+    text = StaticText(name='Text:')
+
+    widget = text.get_root(document, comm=comm)
+
+    assert widget.text == '<b>Text:</b>: '
+
+def test_static_text_repr(document, comm):
+
+    text = StaticText(value=StaticText, name='Text:')
+
+    widget = text.get_root(document, comm=comm)
+
+    assert widget.text == '<b>Text:</b>: &lt;class &#x27;panel.widgets.input.StaticText&#x27;&gt;'
+
+
 
 def test_text_input(document, comm):
 
