@@ -2,6 +2,8 @@ from __future__ import annotations
 
 import pathlib
 
+from collections.abc import Callable
+
 import param
 
 from bokeh.themes import Theme as _BkTheme
@@ -10,7 +12,7 @@ from ..config import config
 from ..io.resources import CDN_DIST
 from ..layout import Accordion
 from ..reactive import ReactiveHTML
-from ..viewable import Viewable
+from ..viewable import Child, Viewable
 from ..widgets import Tabulator
 from ..widgets.indicators import Dial, Number, String
 from .base import (
@@ -137,7 +139,7 @@ class FastWrapper(ReactiveHTML):
     using the Fast design system have access to the Fast CSS variables.
     """
 
-    object = param.ClassSelector(class_=Viewable, allow_refs=False)
+    object = Child()
 
     style = param.ClassSelector(class_=FastStyle)
 
@@ -169,6 +171,10 @@ class FastWrapper(ReactiveHTML):
         """
     }
 
+    def select(
+        self, selector: type | Callable[[Viewable], bool] | None = None
+    ) -> list[Viewable]:
+        return [] if self.object is None else self.object.select(selector)
 
 DEFAULT_STYLE = FastStyle()
 
