@@ -339,4 +339,9 @@ class JSONEditor(Widget):
             "panel.models.jsoneditor", "JSONEditor", isinstance(comm, JupyterComm)
         )
         model = super()._get_model(doc, root, parent, comm)
+        self._register_events('json_edit', model=model, doc=doc, comm=comm)
         return model
+
+    def _process_event(self, event) -> None:
+        if event.event_name == 'json_edit':
+            self.value  = event.data
